==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Test/Gui/Resources/translations/Test_pt-PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Falhas e erros</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descrição</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>Iniciar</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Ajuda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Sobre o ...</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Fechar</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inativo</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progresso</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Restante:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Erros:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Falhas:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Executar:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Testar</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selecionar o nome do teste:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre o UnitTest do FreeCAD</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Direitos de Autor (c) Werner Mayer

FreeCAD UnitTest é parte do FreeCAD e suporta o desenvolvimento dos Testes de Unidade para os módulos próprios.
</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Digite o nome de um objeto invocável que quando chamado, irá retornar um TestCase. Clique 'Iniciar' e o teste produzido será executado. Clique duplo num erro na visualização em árvore para mais informações sobre o mesmo, incluindo o rastreamento do empilhamento.</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Test/Gui/Resources/translations/Test_pt-PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt-PT" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>Unidade de teste FreeCAD</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Falhas e erros</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descrição</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Iniciar</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Ajuda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Sobre o ...</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Fechar</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inativo</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progresso</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Restante:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Erros:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Falhas:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Executar:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Testar</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selecionar o nome do teste:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre o FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Direitos de Autor (c) Werner Mayer

O FreeCAD UnitTest é parte do FreeCAD e suporta o desenvolvimento dos Testes de Unidade para os seus próprios módulos.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Digite o nome de um objeto invocável que quando chamado, irá retornar um TestCase. Clique 'Iniciar' e o teste produzido será executado. Clique duplo num erro na visualização em árvore para mais informação sobre o mesmo, incluindo o rastreamento do empilhamento.</translation>
    </message>
  </context>
</TS>
